@@ -4,16 +4,14 @@ from .serial_entry import serial_pipeline
 from .serial_entry_td3_vae import serial_pipeline_td3_vae
 from .serial_entry_onpolicy import serial_pipeline_onpolicy
 from .serial_entry_offline import serial_pipeline_offline
-from .serial_entry_il import serial_pipeline_il
-from .serial_entry_reward_model_ngu import serial_pipeline_reward_model_ngu
-from .serial_entry_reward_model import serial_pipeline_reward_model
+from .serial_entry_ngu import serial_pipeline_ngu
+from .serial_entry_reward_model_offpolicy import serial_pipeline_reward_model_offpolicy
 from .serial_entry_reward_model_onpolicy import serial_pipeline_reward_model_onpolicy
+from .serial_entry_bc import serial_pipeline_bc
 from .serial_entry_mbrl import serial_pipeline_mbrl
 from .serial_entry_dqfd import serial_pipeline_dqfd
 from .serial_entry_r2d3 import serial_pipeline_r2d3
 from .serial_entry_sqil import serial_pipeline_sqil
-from .serial_entry_trex import serial_pipeline_reward_model_trex
-from .serial_entry_trex_onpolicy import serial_pipeline_reward_model_trex_onpolicy
 from .parallel_entry import parallel_pipeline
 from .application_entry import eval, collect_demo_data, collect_episodic_demo_data, \
       episode_to_transitions
@@ -21,3 +19,8 @@ from .application_entry_trex_collect_data import trex_collecting_data, collect_e
 from .serial_entry_guided_cost import serial_pipeline_guided_cost
 from .serial_entry_gail import serial_pipeline_gail
 from .utils import random_collect
+from .serial_entry_preference_based_irl \
+      import serial_pipeline_preference_based_irl
+from .serial_entry_preference_based_irl_onpolicy \
+      import serial_pipeline_preference_based_irl_onpolicy
+from .application_entry_drex_collect_data import drex_collecting_data
