@@ -8,8 +8,7 @@ from easydict import EasyDict
 from functools import partial
 import gym
 
-from ding.envs.common.env_element import EnvElement, EnvElementInfo
-from ding.envs.env.base_env import BaseEnvTimestep, BaseEnvInfo
+from ding.envs.env.base_env import BaseEnvTimestep
 from ding.envs.env_manager.base_env_manager import EnvState
 from ding.envs.env_manager import BaseEnvManager, SyncSubprocessEnvManager, AsyncSubprocessEnvManager
 from ding.torch_utils import to_tensor, to_ndarray, to_list
@@ -19,7 +18,8 @@ from ding.utils import deep_merge_dicts
 class FakeEnv(object):
 
     def __init__(self, cfg):
-        self._target_time = random.randint(3, 6)
+        self._scale = cfg.scale
+        self._target_time = random.randint(3, 6) * self._scale
         self._current_time = 0
         self._name = cfg['name']
         self._id = time.time()
@@ -57,6 +57,7 @@ class FakeEnv(object):
         self._current_time = 0
         self._stat = stat
         self._state = EnvState.RUN
+        return to_ndarray(torch.randn(3))
 
     def step(self, action):
         assert self._launched
@@ -76,7 +77,7 @@ class FakeEnv(object):
         done = self._current_time >= self._target_time
         if done:
             self._state = EnvState.DONE
-        simulation_time = random.uniform(0.5, 1)
+        simulation_time = random.uniform(0.5, 1) * self._scale
         info = {'name': self._name, 'time': simulation_time, 'tgt': self._target_time, 'cur': self._current_time}
         time.sleep(simulation_time)
         self._current_time += simulation_time
@@ -117,10 +118,34 @@ class FakeAsyncEnv(FakeEnv):
 
     def reset(self, stat=None):
         super().reset(stat)
-        time.sleep(random.randint(1, 3))
+        time.sleep(random.randint(1, 3) * self._scale)
         return to_ndarray(torch.randn(3))
 
 
+class FakeGymEnv(FakeEnv):
+
+    def __init__(self, cfg):
+        super().__init__(cfg)
+        self.metadata = "fake metadata"
+        self.action_space = gym.spaces.Box(low=-2.0, high=2.0, shape=(4, ), dtype=np.float32)
+
+    def random_action(self) -> np.ndarray:
+        random_action = self.action_space.sample()
+        if isinstance(random_action, np.ndarray):
+            pass
+        elif isinstance(random_action, int):
+            random_action = to_ndarray([random_action], dtype=np.int64)
+        elif isinstance(random_action, dict):
+            random_action = to_ndarray(random_action)
+        else:
+            raise TypeError(
+                '`random_action` should be either int/np.ndarray or dict of int/np.ndarray, but get {}: {}'.format(
+                    type(random_action), random_action
+                )
+            )
+        return random_action
+
+
 class FakeModel(object):
 
     def forward(self, obs):
@@ -142,6 +167,7 @@ def get_base_manager_cfg(env_num=4):
     manager_cfg = {
         'env_cfg': [{
             'name': 'name{}'.format(i),
+            'scale': 1.0,
         } for i in range(env_num)],
         'episode_num': 2,
         'reset_timeout': 10,
@@ -155,6 +181,7 @@ def get_subprecess_manager_cfg(env_num=4):
     manager_cfg = {
         'env_cfg': [{
             'name': 'name{}'.format(i),
+            'scale': 1.0,
         } for i in range(env_num)],
         'episode_num': 2,
         #'step_timeout': 8,
@@ -166,6 +193,20 @@ def get_subprecess_manager_cfg(env_num=4):
     return EasyDict(manager_cfg)
 
 
+def get_gym_vector_manager_cfg(env_num=4):
+    manager_cfg = {
+        'env_cfg': [{
+            'name': 'name{}'.format(i),
+        } for i in range(env_num)],
+        'episode_num': 2,
+        'connect_timeout': 8,
+        'step_timeout': 5,
+        'max_retry': 2,
+        'share_memory': True
+    }
+    return EasyDict(manager_cfg)
+
+
 @pytest.fixture(scope='function')
 def setup_base_manager_cfg():
     manager_cfg = get_base_manager_cfg(4)
@@ -174,6 +215,16 @@ def setup_base_manager_cfg():
     return deep_merge_dicts(BaseEnvManager.default_config(), EasyDict(manager_cfg))
 
 
+@pytest.fixture(scope='function')
+def setup_fast_base_manager_cfg():
+    manager_cfg = get_base_manager_cfg(4)
+    env_cfg = manager_cfg.pop('env_cfg')
+    for e in env_cfg:
+        e['scale'] = 0.1
+    manager_cfg['env_fn'] = [partial(FakeEnv, cfg=c) for c in env_cfg]
+    return deep_merge_dicts(BaseEnvManager.default_config(), EasyDict(manager_cfg))
+
+
 @pytest.fixture(scope='function')
 def setup_sync_manager_cfg():
     manager_cfg = get_subprecess_manager_cfg(4)
@@ -191,3 +242,12 @@ def setup_async_manager_cfg():
     manager_cfg['env_fn'] = [partial(FakeAsyncEnv, cfg=c) for c in env_cfg]
     manager_cfg['shared_memory'] = False
     return deep_merge_dicts(AsyncSubprocessEnvManager.default_config(), EasyDict(manager_cfg))
+
+
+@pytest.fixture(scope='function')
+def setup_gym_vector_manager_cfg():
+    manager_cfg = get_subprecess_manager_cfg(4)
+    env_cfg = manager_cfg.pop('env_cfg')
+    manager_cfg['env_fn'] = [partial(FakeGymEnv, cfg=c) for c in env_cfg]
+    manager_cfg['shared_memory'] = False
+    return EasyDict(manager_cfg)
