@@ -211,4 +211,11 @@ class TestSubprocessEnvManager:
             timestep = env_manager.step(action)
             if env_manager.done:
                 break
-        assert all(env_manager._env_episode_count[i] == 1 for i in range(env_manager.env_num))
+            for env_id, t in timestep.items():
+                if t.done and not env_manager.env_state_done(env_id):
+                    env_manager.reset({env_id: None})
+        assert all(
+            env_manager._env_episode_count[i] == setup_async_manager_cfg['episode_num']
+            for i in range(env_manager.env_num)
+        )
+        assert all(env_manager._env_states[i] == EnvState.DONE for i in range(env_manager.env_num))
