@@ -102,6 +102,12 @@ class CQLPolicy(SACPolicy):
 
             # (str type) action_space: Use reparameterization trick for continous action
             action_space='reparameterization',
+
+            # (int) Hidden size for actor network head.
+            actor_head_hidden_size=256,
+
+            # (int) Hidden size for critic network head.
+            critic_head_hidden_size=256,
         ),
         learn=dict(
             # (bool) Whether to use multi gpu
