@@ -1,7 +1,6 @@
 import copy
 import random
-from typing import Tuple
-from typing import Union, Dict, List
+from typing import Union, Tuple, Any, Dict, List
 
 import numpy as np
 import torch
@@ -70,6 +69,141 @@ def collect_data_episodic(data_in):
     return res, is_null_list
 
 
+class RndNetwork(nn.Module):
+
+    def __init__(self, obs_shape: Union[int, SequenceType], hidden_size_list: SequenceType) -> None:
+        super(RndNetwork, self).__init__()
+        if isinstance(obs_shape, int) or len(obs_shape) == 1:
+            self.target = FCEncoder(obs_shape, hidden_size_list)
+            self.predictor = FCEncoder(obs_shape, hidden_size_list)
+        elif len(obs_shape) == 3:
+            self.target = ConvEncoder(obs_shape, hidden_size_list)
+            self.predictor = ConvEncoder(obs_shape, hidden_size_list)
+        else:
+            raise KeyError(
+                "not support obs_shape for pre-defined encoder: {}, "
+                "please customize your own RND model".format(obs_shape)
+            )
+        for param in self.target.parameters():
+            param.requires_grad = False
+
+    def forward(self, obs: torch.Tensor) -> Tuple[torch.Tensor, torch.Tensor]:
+        predict_feature = self.predictor(obs)
+        with torch.no_grad():
+            target_feature = self.target(obs)
+        return predict_feature, target_feature
+
+
+@REWARD_MODEL_REGISTRY.register('rnd-ngu')
+class RndNGURewardModel(BaseRewardModel):
+    config = dict(
+        type='rnd-ngu',
+        intrinsic_reward_type='add',
+        learning_rate=1e-3,
+        batch_size=64,
+        hidden_size_list=[64, 64, 128],
+        update_per_collect=100,
+    )
+
+    def __init__(self, config: EasyDict, device: str, tb_logger: 'SummaryWriter') -> None:  # noqa
+        super(RndNGURewardModel, self).__init__()
+        self.cfg = config
+        assert device == "cpu" or device.startswith("cuda")
+        self.device = device
+        self.tb_logger = tb_logger
+        self.reward_model = RndNetwork(config.obs_shape, config.hidden_size_list)
+        self.reward_model.to(self.device)
+        self.intrinsic_reward_type = config.intrinsic_reward_type
+        assert self.intrinsic_reward_type in ['add', 'new', 'assign']
+        self.train_data_total = []
+        self.train_data = []
+        self.opt = optim.Adam(self.reward_model.predictor.parameters(), config.learning_rate)
+        self.estimate_cnt_rnd = 0
+        self._running_mean_std_rnd = RunningMeanStd(epsilon=1e-4)
+        self.only_use_last_five_frames = config.only_use_last_five_frames_for_icm_rnd
+
+    def _train(self) -> None:
+        train_data: list = random.sample(list(self.train_data_cur), self.cfg.batch_size)
+
+        train_data: torch.Tensor = torch.stack(train_data).to(self.device)
+
+        predict_feature, target_feature = self.reward_model(train_data)
+        loss = F.mse_loss(predict_feature, target_feature.detach())
+        self.opt.zero_grad()
+        loss.backward()
+        self.opt.step()
+
+    def train(self) -> None:
+        if self.only_use_last_five_frames:
+            # self.train_obs shape list(list) [batch_size,seq_length,N
+
+            # stack episode dim
+            self.train_obs = [torch.stack(episode_obs[-5:], dim=0) for episode_obs in self.train_data_total]
+
+            # stack batch dim
+            # way 1
+            if isinstance(self.cfg.obs_shape, int):
+                self.train_data_cur = torch.stack(
+                    self.train_obs, dim=0
+                ).view(len(self.train_obs) * len(self.train_obs[0]), self.cfg.obs_shape)
+            else:  # len(self.cfg.obs_shape) == 3 for image obs
+                self.train_data_cur = torch.stack(
+                    self.train_obs, dim=0
+                ).view(len(self.train_obs) * self.train_obs[0].shape[0], *self.cfg.obs_shape)
+            # way 2
+            # self.train_data_cur = torch.cat(self.train_obs, 0)
+
+        else:
+            self.train_data_cur = sum(self.train_data_total, [])
+            # another implementation way
+            # tmp = []
+            # for i in range(len(self.train_data)):
+            #     tmp += self.train_data[i]
+            # self.train_data = tmp
+
+        for _ in range(self.cfg.update_per_collect):
+            self._train()
+
+    def estimate(self, data: list) -> torch.Tensor:
+        """
+        Rewrite the reward key in each row of the data.
+        """
+        obs, is_null = collect_data_rnd(data)
+        if isinstance(obs[0], list):  # if obs shape list( list(torch.tensor) )
+            obs = sum(obs, [])
+
+        obs = torch.stack(obs).to(self.device)
+
+        with torch.no_grad():
+            predict_feature, target_feature = self.reward_model(obs)
+            reward = F.mse_loss(predict_feature, target_feature, reduction='none').mean(dim=1)
+            self._running_mean_std_rnd.update(reward.cpu().numpy())
+            # transform to mean 1 std 1
+            reward = 1 + (reward - self._running_mean_std_rnd.mean) / (self._running_mean_std_rnd.std + 1e-11)
+            self.estimate_cnt_rnd += 1
+            self.tb_logger.add_scalar('rnd_reward/rnd_reward_max', reward.max(), self.estimate_cnt_rnd)
+            self.tb_logger.add_scalar('rnd_reward/rnd_reward_mean', reward.mean(), self.estimate_cnt_rnd)
+            self.tb_logger.add_scalar('rnd_reward/rnd_reward_min', reward.min(), self.estimate_cnt_rnd)
+        return reward
+
+    def collect_data(self, data: list) -> None:
+        self.train_data_total.extend(collect_data_and_exclude_null_data_rnd(data))
+
+    def clear_data(self) -> None:
+        self.train_data_total.clear()
+
+    def reward_deepcopy(self, train_data):
+        """
+        this method deepcopy reward part in train_data, and other parts keep shallow copy
+        to avoid the reward part of train_data in the replay buffer be incorrectly modified.
+        """
+        train_data_reward_deepcopy = [
+            {k: copy.deepcopy(v) if k == 'reward' else v
+             for k, v in sample.items()} for sample in train_data
+        ]
+        return train_data_reward_deepcopy
+
+
 class InverseNetwork(nn.Module):
 
     def __init__(self, obs_shape: Union[int, SequenceType], action_shape, hidden_size_list: SequenceType) -> None:
@@ -200,18 +334,15 @@ class EpisodicNGURewardModel(BaseRewardModel):
 
         if s > siminarity_max:
             print('s > siminarity_max:', s.max(), s.min())
-            return torch.tensor(0)  # todo
-        if torch.isnan(s):
-            print('torch.isnan(s):', s.max(), s.min())
-            return torch.tensor(0)  # todo
+            return torch.tensor(0)  # NOTE
         return 1 / s
-        # torch.tensor(1 / s)
         # average value 1/( ( 10* 1e-4/(1+1e-4) )**(1/2)+1e-3 ) = 30
 
-    def estimate(self, data: list) -> None:
+    def estimate(self, data: list) -> torch.Tensor:
         """
         Rewrite the reward key in each row of the data.
         """
+
         obs, is_null = collect_data_episodic(data)
         # obs shape list(list()) [batch_size,seq_length,obs_dim]
         batch_size = len(obs)
@@ -249,7 +380,7 @@ class EpisodicNGURewardModel(BaseRewardModel):
                         episodic_reward[i].append(reward)
 
                 if torch.nonzero(torch.tensor(is_null[i]).float()).shape[0] != 0:
-                    # TODO if have null padding, the episodic_reward should be 0
+                    # TODO(pu): if have null padding, the episodic_reward should be 0
                     not_null_index = torch.nonzero(torch.tensor(is_null[i]).float()).squeeze(-1)
                     null_start_index = int(torch.nonzero(torch.tensor(is_null[i]).float()).squeeze(-1)[0])
                     # add the number of null transitions in i'th sequence in batch
@@ -262,14 +393,14 @@ class EpisodicNGURewardModel(BaseRewardModel):
             # list(list(tensor)) - > tensor
             tmp = [torch.stack(episodic_reward_tmp, dim=0) for episodic_reward_tmp in episodic_reward]
             # stack batch dim
-            episodic_reward = torch.stack(tmp, dim=0)  # TODO image
+            episodic_reward = torch.stack(tmp, dim=0)  # TODO(pu): image case
             episodic_reward = episodic_reward.view(-1)  # torch.Size([32, 42]) -> torch.Size([32*42]
 
             episodic_reward_real_mean = sum(episodic_reward) / (
                 batch_size * seq_length - null_cnt
-            )  # TODO recompute mean
+            )  # TODO(pu): recompute mean
             self.estimate_cnt_episodic += 1
-            self._running_mean_std_episodic_reward.update(episodic_reward.cpu().numpy())  # .cpu().numpy() # TODO
+            self._running_mean_std_episodic_reward.update(episodic_reward.cpu().numpy())
 
             self.tb_logger.add_scalar(
                 'episodic_reward/episodic_reward_max', episodic_reward.max(), self.estimate_cnt_episodic
@@ -311,206 +442,91 @@ class EpisodicNGURewardModel(BaseRewardModel):
         self.train_obs_total = []
         self.train_action_total = []
 
-
-class RndNetwork(nn.Module):
-
-    def __init__(self, obs_shape: Union[int, SequenceType], hidden_size_list: SequenceType) -> None:
-        super(RndNetwork, self).__init__()
-        if isinstance(obs_shape, int) or len(obs_shape) == 1:
-            self.target = FCEncoder(obs_shape, hidden_size_list)
-            self.predictor = FCEncoder(obs_shape, hidden_size_list)
-        elif len(obs_shape) == 3:
-            self.target = ConvEncoder(obs_shape, hidden_size_list)
-            self.predictor = ConvEncoder(obs_shape, hidden_size_list)
-        else:
-            raise KeyError(
-                "not support obs_shape for pre-defined encoder: {}, "
-                "please customize your own RND model".format(obs_shape)
+    def fusion_reward(
+        self, train_data, inter_episodic_reward, episodic_reward, nstep, collector_env_num, tb_logger, estimate_cnt
+    ):
+        # NOTE: deepcopy reward part of train_data is very important,
+        # otherwise the reward of train_data in the replay buffer will be incorrectly modified.
+        data = self.reward_deepcopy(train_data)
+        estimate_cnt += 1
+        # index_to_eps = {i: 0.4 ** (1 + 8 * i / (self._env_num - 1)) for i in range(self._env_num)}
+        index_to_beta = {
+            i: 0.3 * torch.sigmoid(torch.tensor(10 * (2 * i - (collector_env_num - 2)) / (collector_env_num - 2)))
+            for i in range(collector_env_num)
+        }
+        index_to_gamma = {
+            i: 1 - torch.exp(
+                (
+                    (collector_env_num - 1 - i) * torch.log(torch.tensor(1 - 0.997)) +
+                    i * torch.log(torch.tensor(1 - 0.99))
+                ) / (collector_env_num - 1)
             )
-        for param in self.target.parameters():
-            param.requires_grad = False
-
-    def forward(self, obs: torch.Tensor) -> Tuple[torch.Tensor, torch.Tensor]:
-        predict_feature = self.predictor(obs)
-        with torch.no_grad():
-            target_feature = self.target(obs)
-        return predict_feature, target_feature
-
-
-@REWARD_MODEL_REGISTRY.register('rnd-ngu')
-class RndNGURewardModel(BaseRewardModel):
-    config = dict(
-        type='rnd-ngu',
-        intrinsic_reward_type='add',
-        learning_rate=1e-3,
-        batch_size=64,
-        hidden_size_list=[64, 64, 128],
-        update_per_collect=100,
-    )
-
-    def __init__(self, config: EasyDict, device: str, tb_logger: 'SummaryWriter') -> None:  # noqa
-        super(RndNGURewardModel, self).__init__()
-        self.cfg = config
-        assert device == "cpu" or device.startswith("cuda")
-        self.device = device
-        self.tb_logger = tb_logger
-        self.reward_model = RndNetwork(config.obs_shape, config.hidden_size_list)
-        self.reward_model.to(self.device)
-        self.intrinsic_reward_type = config.intrinsic_reward_type
-        assert self.intrinsic_reward_type in ['add', 'new', 'assign']
-        self.train_data_total = []
-        self.train_data = []
-        self.opt = optim.Adam(self.reward_model.predictor.parameters(), config.learning_rate)
-        self.estimate_cnt_rnd = 0
-        self._running_mean_std_rnd = RunningMeanStd(epsilon=1e-4)
-        self.only_use_last_five_frames = config.only_use_last_five_frames_for_icm_rnd
-
-    def _train(self) -> None:
-        train_data: list = random.sample(list(self.train_data_cur), self.cfg.batch_size)
-
-        train_data: torch.Tensor = torch.stack(train_data).to(self.device)
-
-        predict_feature, target_feature = self.reward_model(train_data)
-        loss = F.mse_loss(predict_feature, target_feature.detach())
-        self.opt.zero_grad()
-        loss.backward()
-        self.opt.step()
-
-    def train(self) -> None:
-        if self.only_use_last_five_frames:
-            # self.train_obs shape list(list) [batch_size,seq_length,N
-
-            # stack episode dim
-            self.train_obs = [torch.stack(episode_obs[-5:], dim=0) for episode_obs in self.train_data_total]
-
-            # stack batch dim
-            # way 1
-            if isinstance(self.cfg.obs_shape, int):
-                self.train_data_cur = torch.stack(
-                    self.train_obs, dim=0
-                ).view(len(self.train_obs) * len(self.train_obs[0]), self.cfg.obs_shape)
-            else:  # len(self.cfg.obs_shape) == 3 for image obs
-                self.train_data_cur = torch.stack(
-                    self.train_obs, dim=0
-                ).view(len(self.train_obs) * self.train_obs[0].shape[0], *self.cfg.obs_shape)
-            # way 2
-            # self.train_data_cur = torch.cat(self.train_obs, 0)
+            for i in range(collector_env_num)
+        }
+        batch_size = len(data)
+        seq_length = len(data[0]['reward'])
+        device = data[0]['reward'][0].device
+        intrinsic_reward_type = 'add'
+        intrisic_reward = episodic_reward * torch.clamp(inter_episodic_reward, min=1, max=5)
+        tb_logger.add_scalar('intrinsic_reward/intrinsic_reward_max', intrisic_reward.max(), estimate_cnt)
+        tb_logger.add_scalar('intrinsic_reward/intrinsic_reward_mean', intrisic_reward.mean(), estimate_cnt)
+        tb_logger.add_scalar('intrinsic_reward/intrinsic_reward_min', intrisic_reward.min(), estimate_cnt)
 
+        if not isinstance(data[0], (list, dict)):
+            # not rnn based rl algorithm
+            intrisic_reward = intrisic_reward.to(device)
+            intrisic_reward = torch.chunk(intrisic_reward, intrisic_reward.shape[0], dim=0)
+            for item, rew in zip(data, intrisic_reward):
+                if intrinsic_reward_type == 'add':
+                    item['reward'] += rew * index_to_beta[data['beta']]
         else:
-            self.train_data_cur = sum(self.train_data_total, [])
-            # another implementation way
-            # tmp = []
-            # for i in range(len(self.train_data)):
-            #     tmp += self.train_data[i]
-            # self.train_data = tmp
+            # rnn based rl algorithm
+            intrisic_reward = intrisic_reward.to(device)
 
-        for _ in range(self.cfg.update_per_collect):
-            self._train()
-        # self.clear_data()
+            # tensor to tuple
+            intrisic_reward = torch.chunk(intrisic_reward, int(intrisic_reward.shape[0]), dim=0)
 
-    def estimate(self, data: list) -> None:
-        """
-        Rewrite the reward key in each row of the data.
-        """
-        obs, is_null = collect_data_rnd(data)
-        if isinstance(obs[0], list):  # if obs shape list( list(torch.tensor) )
-            obs = sum(obs, [])
+            if len(data[0]['obs'][0].shape) == 3:
+                # atari, obs is image
+                last_rew_weight = 1
+            else:
+                # lularlander, minigrid
+                last_rew_weight = seq_length
 
-        obs = torch.stack(obs).to(self.device)
+            # this is for the nstep rl algorithms
+            for i in range(batch_size):  # batch_size typically 64
+                for j in range(seq_length):  # burnin+unroll_len is the sequence length, e.g. 100=2+98
+                    if j < seq_length - nstep:
+                        intrinsic_reward = torch.cat(
+                            [intrisic_reward[i * seq_length + j + k] for k in range(nstep)], dim=0
+                        )
+                        # if intrinsic_reward_type == 'add':
+                        if not data[i]['null'][j]:
+                            # if data[i]['null'][j]==True, means its's null data, only the not null data,
+                            # we add aintrinsic_reward reward
+                            if data[i]['done'][j]:
+                                # if not null data, and data[i]['done'][j]==True, so this is the last nstep transition
+                                # in the original data.
+                                for k in reversed(range(nstep)):
+                                    # here we want to find the last nonzero reward in the nstep reward list:
+                                    # data[i]['reward'][j], that is also the last reward in the sequence, here,
+                                    # we set the sequence length is large enough,
+                                    # so we can consider the sequence as the whole episode plus null_padding
 
-        with torch.no_grad():
-            predict_feature, target_feature = self.reward_model(obs)
-            reward = F.mse_loss(predict_feature, target_feature, reduction='none').mean(dim=1)
-            self._running_mean_std_rnd.update(reward.cpu().numpy())
-            # transform to mean 1 std 1
-            reward = 1 + (reward - self._running_mean_std_rnd.mean) / (self._running_mean_std_rnd.std + 1e-11)
-            self.estimate_cnt_rnd += 1
-            self.tb_logger.add_scalar('rnd_reward/rnd_reward_max', reward.max(), self.estimate_cnt_rnd)
-            self.tb_logger.add_scalar('rnd_reward/rnd_reward_mean', reward.mean(), self.estimate_cnt_rnd)
-            self.tb_logger.add_scalar('rnd_reward/rnd_reward_min', reward.min(), self.estimate_cnt_rnd)
-        return reward
+                                    # TODO(pu): what should we do if the last reward in the whole episode is zero?
+                                    if data[i]['reward'][j][k] != 0:
+                                        # find the last one that is nonzero, and enlarging <seq_length> times
+                                        tmp = copy.deepcopy(data[i]['reward'][j][k])  # should deepcopy to avoid
+                                        data[i]['reward'][j] += intrinsic_reward * index_to_beta[int(
+                                            data[i]['beta'][j]
+                                        )]
+                                        # data[i]['reward'][j][k] = last_rew_weight * tmp + intrinsic_reward[k]
+                                        # * index_to_beta[int(data[i]['beta'][j])]
+                                        data[i]['reward'][j][k] = last_rew_weight * tmp
+                                        # substitute the kth reward in the list data[i]['reward'][j] with <seq_length>
+                                        # times amplified reward
+                                        break
+                            else:
+                                data[i]['reward'][j] += intrinsic_reward * index_to_beta[int(data[i]['beta'][j])]
 
-    def collect_data(self, data: list) -> None:
-        self.train_data_total.extend(collect_data_and_exclude_null_data_rnd(data))
-
-    def clear_data(self) -> None:
-        self.train_data_total.clear()
-
-
-def fusion_reward(data, inter_episodic_reward, episodic_reward, nstep, collector_env_num, tb_logger, estimate_cnt):
-    estimate_cnt += 1
-    # index_to_eps = {i: 0.4 ** (1 + 8 * i / (self._env_num - 1)) for i in range(self._env_num)}
-    index_to_beta = {
-        i: 0.3 * torch.sigmoid(torch.tensor(10 * (2 * i - (collector_env_num - 2)) / (collector_env_num - 2)))
-        for i in range(collector_env_num)
-    }
-    index_to_gamma = {
-        i: 1 - torch.exp(
-            ((collector_env_num - 1 - i) * torch.log(torch.tensor(1 - 0.997)) + i * torch.log(torch.tensor(1 - 0.99))) /
-            (collector_env_num - 1)
-        )
-        for i in range(collector_env_num)
-    }
-    batch_size = len(data)
-    seq_length = len(data[0]['reward'])
-    device = data[0]['reward'][0].device
-    intrinsic_reward_type = 'add'
-    intrisic_reward = episodic_reward * torch.clamp(inter_episodic_reward, min=1, max=5)
-    tb_logger.add_scalar('intrinsic_reward/intrinsic_reward_max', intrisic_reward.max(), estimate_cnt)
-    tb_logger.add_scalar('intrinsic_reward/intrinsic_reward_mean', intrisic_reward.mean(), estimate_cnt)
-    tb_logger.add_scalar('intrinsic_reward/intrinsic_reward_min', intrisic_reward.min(), estimate_cnt)
-
-    if not isinstance(data[0], (list, dict)):
-        # not rnn based rl algorithm
-        intrisic_reward = intrisic_reward.to(device)
-        intrisic_reward = torch.chunk(intrisic_reward, intrisic_reward.shape[0], dim=0)
-        for item, rew in zip(data, intrisic_reward):
-            if intrinsic_reward_type == 'add':
-                item['reward'] += rew * index_to_beta[data['beta']]
-    else:
-        # rnn based rl algorithm
-        intrisic_reward = intrisic_reward.to(device)
-
-        # tensor to tuple
-        intrisic_reward = torch.chunk(intrisic_reward, int(intrisic_reward.shape[0]), dim=0)
-
-        if len(data[0]['obs'][0].shape) == 3:
-            # atari, obs is image
-            last_rew_weight = 1
-        else:
-            # lularlander, minigrid
-            last_rew_weight = seq_length
-
-        # this is for the nstep rl algorithms
-        for i in range(batch_size):  # batch_size typically 64
-            for j in range(seq_length):  # burnin+unroll_len is the sequence length, e.g. 100=2+98
-                if j < seq_length - nstep:
-                    intrinsic_reward = torch.cat([intrisic_reward[i * seq_length + j + k] for k in range(nstep)], dim=0)
-                    # if intrinsic_reward_type == 'add':
-                    if not data[i]['null'][j]:
-                        # if data[i]['null'][j]==True, means its's null data, only the not null data,
-                        # we add aintrinsic_reward reward
-                        if data[i]['done'][j]:
-                            # if not null data, and data[i]['done'][j]==True, so this is the last nstep transition
-                            # in the original data.
-                            for k in reversed(range(nstep)):
-                                # here we want to find the last nonzero reward in the nstep reward list:
-                                # data[i]['reward'][j], that is also the last reward in the sequence, here,
-                                # we set the sequence length is large enough,
-                                # so we can consider the sequence as the whole episode plus null_padding
-
-                                # TODO(pu): what should we do if the last reward in the whole episode is zero?
-                                if data[i]['reward'][j][k] != 0:
-                                    # find the last one that is nonzero, and enlarging <seq_length> times
-                                    tmp = copy.deepcopy(data[i]['reward'][j][k])  # should deepcopy to avoid
-                                    data[i]['reward'][j] += intrinsic_reward * index_to_beta[int(data[i]['beta'][j])]
-                                    # data[i]['reward'][j][k] = last_rew_weight * tmp + intrinsic_reward[k]
-                                    # * index_to_beta[int(data[i]['beta'][j])]
-                                    data[i]['reward'][j][k] = last_rew_weight * tmp
-                                    # substitute the kth reward in the list data[i]['reward'][j] with <seq_length>
-                                    # times amplified reward
-                                    break
-                        else:
-                            data[i]['reward'][j] += intrinsic_reward * index_to_beta[int(data[i]['beta'][j])]
-
-    return data, estimate_cnt
+        return data, estimate_cnt
