@@ -9,7 +9,7 @@ def acer_policy_error(
         q_values: torch.Tensor,
         q_retraces: torch.Tensor,
         v_pred: torch.Tensor,
-        target_pi: torch.Tensor,
+        target_logit: torch.Tensor,
         actions: torch.Tensor,
         ratio: torch.Tensor,
         c_clip_ratio: float = 10.0
@@ -42,13 +42,13 @@ def acer_policy_error(
     with torch.no_grad():
         advantage_retraces = q_retraces - v_pred  # shape T,B,1
         advantage_native = q_values - v_pred  # shape T,B,env_action_shape
-    actor_loss = ratio.gather(-1, actions).clamp(max=c_clip_ratio
-                                                 ) * advantage_retraces * (target_pi.gather(-1, actions) +
-                                                                           EPS).log()  # shape T,B,1
+    actor_loss = ratio.gather(-1, actions).clamp(max=c_clip_ratio) * advantage_retraces * target_logit.gather(
+        -1, actions
+    )  # shape T,B,1
 
     # bias correction term, the first target_pi will not calculate gradient flow
-    bias_correction_loss = (1.0-c_clip_ratio/(ratio+EPS)).clamp(min=0.0)*target_pi.detach() * \
-        advantage_native*(target_pi+EPS).log()  # shape T,B,env_action_shape
+    bias_correction_loss = (1.0-c_clip_ratio/(ratio+EPS)).clamp(min=0.0)*torch.exp(target_logit).detach() * \
+        advantage_native*target_logit  # shape T,B,env_action_shape
     bias_correction_loss = bias_correction_loss.sum(-1, keepdim=True)
     return actor_loss, bias_correction_loss
 
@@ -76,7 +76,8 @@ def acer_value_error(q_values, q_retraces, actions):
 
 
 def acer_trust_region_update(
-        actor_gradients: List[torch.Tensor], target_pi: torch.Tensor, avg_pi: torch.Tensor, trust_region_value: float
+        actor_gradients: List[torch.Tensor], target_logit: torch.Tensor, avg_logit: torch.Tensor,
+        trust_region_value: float
 ) -> List[torch.Tensor]:
     """
     Overview:
@@ -93,7 +94,7 @@ def acer_trust_region_update(
         - avg_pi (:obj:`torch.FloatTensor`): :math:`(T, B, N)`
     """
     with torch.no_grad():
-        KL_gradients = [(avg_pi / (target_pi + EPS))]
+        KL_gradients = [torch.exp(avg_logit)]
     update_gradients = []
     # TODO: here is only one elements in this list.Maybe will use to more elements in the future
     actor_gradient = actor_gradients[0]
