@@ -161,8 +161,11 @@ class Adder(object):
 
             def null_padding():
                 template = copy.deepcopy(residual[0])
-                template['null'] = True  # TODO(pu)
-                template['obs'] = torch.zeros_like(template['obs'])
+                template['null'] = True
+                if isinstance(template['obs'], dict):
+                    template['obs'] = {k: torch.zeros_like(v) for k, v in template['obs'].items()}
+                else:
+                    template['obs'] = torch.zeros_like(template['obs'])
                 # template['action'] = -1 * torch.ones_like(template['action']) # TODO(pu)
                 template['action'] = torch.zeros_like(template['action'])
                 template['done'] = True
