@@ -1,6 +1,6 @@
 from .checkpoint_helper import build_checkpoint_helper, CountVar, auto_checkpoint
 from .data_helper import to_device, to_tensor, to_ndarray, to_list, to_dtype, same_shape, tensor_to_list, \
-    build_log_buffer, CudaFetcher, get_tensor_data
+    build_log_buffer, CudaFetcher, get_tensor_data, unsqueeze
 from .distribution import CategoricalPd, CategoricalPdPytorch
 from .loss import *
 from .metric import levenshtein_distance, hamming_distance
