@@ -9,4 +9,4 @@ from .transformer import Transformer
 from .scatter_connection import ScatterConnection
 from .resnet import resnet18, ResNet
 from .gumbel_softmax import GumbelSoftmax
-from .gtrxl import GTrXL
+from .gtrxl import GTrXL, GRUGatingUnit
