@@ -58,12 +58,12 @@ class GRUGatingUnit(torch.nn.Module):
             initializes the agent close to a Markovian policy (ignore attention at the beginning).
         """
         super(GRUGatingUnit, self).__init__()
-        self.Wr = torch.nn.Linear(input_dim, input_dim)
-        self.Ur = torch.nn.Linear(input_dim, input_dim)
-        self.Wz = torch.nn.Linear(input_dim, input_dim)
-        self.Uz = torch.nn.Linear(input_dim, input_dim)
-        self.Wg = torch.nn.Linear(input_dim, input_dim)
-        self.Ug = torch.nn.Linear(input_dim, input_dim)
+        self.Wr = torch.nn.Linear(input_dim, input_dim, bias=False)
+        self.Ur = torch.nn.Linear(input_dim, input_dim, bias=False)
+        self.Wz = torch.nn.Linear(input_dim, input_dim, bias=False)
+        self.Uz = torch.nn.Linear(input_dim, input_dim, bias=False)
+        self.Wg = torch.nn.Linear(input_dim, input_dim, bias=False)
+        self.Ug = torch.nn.Linear(input_dim, input_dim, bias=False)
         self.bg = nn.Parameter(torch.full([input_dim], bg))  # bias
         self.sigmoid = torch.nn.Sigmoid()
         self.tanh = torch.nn.Tanh()
@@ -208,7 +208,7 @@ class AttentionXL(torch.nn.Module):
         self.project_pos = fc_block(input_dim, head_dim * head_num)  # project the positional embedding
         self.scale = 1 / (head_dim ** 0.5)  # for scaled dot product attention
 
-    def _rel_shift(self, x: torch.Tensor):
+    def _rel_shift(self, x: torch.Tensor, zero_upper: bool = False):
         """
         Overview:
             Relatively shift the attention score matrix.
@@ -220,21 +220,23 @@ class AttentionXL(torch.nn.Module):
             1) Append one "column" of zeros to the left
             2) Reshape the matrix from [3 x 4] into [4 x 3]
             3) Remove the first "row"
-            4) Mask out the upper triangle
+            4) Mask out the upper triangle (optional)
         .. note::
             See the following material for better understanding:
                 https://github.com/kimiyoung/transformer-xl/issues/8
                 https://arxiv.org/pdf/1901.02860.pdf (Appendix B)
         Arguments:
             - x (:obj:`torch.Tensor`): input tensor of shape (cur_seq, full_seq, bs, head_num).
+            - zero_upper (:obj:`bool`): if True set the upper-right triangle to zero.
         Returns:
             - x (:obj:`torch.Tensor`): input after relative shift. Shape (cur_seq, full_seq, bs, head_num).
         """
         x_padded = F.pad(x, [1, 0])  # step 1
         x_padded = x_padded.view(x.size(0), x.size(1), x.size(3) + 1, x.size(2))  # step 2
         x = x_padded[:, :, 1:].view_as(x)  # step 3
-        ones = torch.ones((x.size(2), x.size(3))).unsqueeze(0).unsqueeze(0)
-        x = x * torch.tril(ones.to(x.device), x.size(3) - x.size(2))  # step 4
+        if zero_upper:
+            ones = torch.ones((x.size(2), x.size(3))).unsqueeze(0).unsqueeze(0)
+            x = x * torch.tril(ones.to(x.device), x.size(3) - x.size(2))  # step 4
         return x
 
     def forward(
@@ -463,6 +465,9 @@ class GTrXL(nn.Module):
             torch.nn.Parameter(torch.zeros(self.head_num, self.head_dim)),
             torch.nn.Parameter(torch.zeros(self.head_num, self.head_dim)),
         )
+        self.att_mask = {}  # create an attention mask for each different seq_len, in this way we don't need to create a
+        # new one each time we call the forward method
+        self.pos_embedding_dict = {}  # create a pos embedding for each different seq_len
 
     def reset_memory(self, batch_size: Optional[int] = None, state: Optional[torch.Tensor] = None):
         r"""
@@ -528,16 +533,24 @@ class GTrXL(nn.Module):
         prev_seq = self.memory_len
         full_seq = cur_seq + prev_seq
 
-        # TODO: add padding to attention mask, https://huggingface.co/docs/transformers/preprocessing
-        dec_attn_mask = (
-            torch.triu(
-                torch.ones((cur_seq, full_seq)),
-                diagonal=1 + prev_seq,
-            ).bool().unsqueeze(-1).to(x.device)
-        )  # cur_seq x full_seq x 1
+        if cur_seq in self.att_mask.keys():
+            attn_mask = self.att_mask[cur_seq]
+        else:
+            attn_mask = (
+                torch.triu(
+                    torch.ones((cur_seq, full_seq)),
+                    diagonal=1 + prev_seq,  # fixed in train, eval, collect
+                ).bool().unsqueeze(-1).to(x.device)
+            )  # cur_seq x full_seq x 1
+            self.att_mask[cur_seq] = attn_mask
 
-        pos_ips = torch.arange(full_seq - 1, -1, -1.0, dtype=torch.float)  # full_seq
-        pos_embedding = self.dropout(self.pos_embedding(pos_ips.to(x.device)))  # full_seq x 1 x embedding_dim
+        if cur_seq in self.pos_embedding_dict.keys():
+            pos_embedding = self.pos_embedding_dict[cur_seq]
+        else:
+            pos_ips = torch.arange(full_seq - 1, -1, -1.0, dtype=torch.float)  # full_seq
+            pos_embedding = self.pos_embedding(pos_ips.to(x.device))
+            self.pos_embedding_dict[cur_seq] = pos_embedding
+        pos_embedding = self.dropout(pos_embedding)  # full_seq x 1 x embedding_dim
 
         hidden_state = [x]
         out = x
@@ -548,7 +561,7 @@ class GTrXL(nn.Module):
                 pos_embedding,
                 self.u,
                 self.v,
-                mask=dec_attn_mask,
+                mask=attn_mask,
                 memory=memory[i],  # (layer_num+1) x memory_len x batch_size x embedding_dim
             )  # cur_seq x bs x embedding_dim
             hidden_state.append(out.clone())
