@@ -189,17 +189,21 @@ class SampleSerialCollector(ISerialCollector):
         """
         self.close()
 
-    def collect(self,
-                n_sample: Optional[int] = None,
-                train_iter: int = 0,
-                policy_kwargs: Optional[dict] = None) -> List[Any]:
+    def collect(
+            self,
+            n_sample: Optional[int] = None,
+            train_iter: int = 0,
+            drop_extra: bool = True,
+            policy_kwargs: Optional[dict] = None
+    ) -> List[Any]:
         """
         Overview:
-            Collect `n_sample` data with policy_kwargs, which is already trained `train_iter` iterations
+            Collect `n_sample` data with policy_kwargs, which is already trained `train_iter` iterations.
         Arguments:
-            - n_sample (:obj:`int`): the number of collecting data sample
-            - train_iter (:obj:`int`): the number of training iteration
-            - policy_kwargs (:obj:`dict`): the keyword args for policy forward
+            - n_sample (:obj:`int`): The number of collecting data sample.
+            - train_iter (:obj:`int`): The number of training iteration when calling collect method.
+            - drop_extra (:obj:`bool`): Whether to drop extra return_data more than `n_sample`.
+            - policy_kwargs (:obj:`dict`): The keyword args for policy forward.
         Returns:
             - return_data (:obj:`List`): A list containing training samples.
         """
@@ -210,8 +214,8 @@ class SampleSerialCollector(ISerialCollector):
                 n_sample = self._default_n_sample
         if n_sample % self._env_num != 0:
             one_time_warning(
-                "Please make sure env_num is divisible by n_sample: {}/{}, which may cause convergence \
-                problems in a few algorithms".format(n_sample, self._env_num)
+                "Please make sure env_num is divisible by n_sample: {}/{}, ".format(n_sample, self._env_num) +
+                "which may cause convergence problems in a few algorithms"
             )
         if policy_kwargs is None:
             policy_kwargs = {}
@@ -245,7 +249,7 @@ class SampleSerialCollector(ISerialCollector):
                         self._env.reset({env_id: None})
                         self._policy.reset([env_id])
                         self._reset_stat(env_id)
-                        self._logger.info('env_id {}, abnormal step {}', env_id, timestep.info)
+                        self._logger.info('Env{} returns a abnormal step, its info is {}'.format(env_id, timestep.info))
                         continue
                     transition = self._policy.process_transition(
                         self._obs_pool[env_id], self._policy_output_pool[env_id], timestep
@@ -297,7 +301,10 @@ class SampleSerialCollector(ISerialCollector):
             for env_id in range(self._env_num):
                 self._reset_stat(env_id)
 
-        return return_data[:n_sample]
+        if drop_extra:
+            return return_data[:n_sample]
+        else:
+            return return_data
 
     def _output_log(self, train_iter: int) -> None:
         """
