@@ -74,16 +74,16 @@ class FakePolicy(Policy):
         data_id = list(data.keys())
         data = default_collate(list(data.values()))
         self.policy_sleep(random_change(self._forward_time))
-        output = {'action': torch.ones(data.shape[0], 2)}
+        output = {'action': torch.ones(data.shape[0], 1).long()}
         output = default_decollate(output)
         output = {i: d for i, d in zip(data_id, output)}
         return output
 
-    def _process_transition(self, obs: Any, armor_output: dict, timestep: namedtuple) -> dict:
+    def _process_transition(self, obs: Any, model_output: dict, timestep: namedtuple) -> dict:
         transition = {
             'obs': obs,
             'next_obs': timestep.obs,
-            'action': armor_output['action'],
+            'action': model_output['action'],
             'reward': timestep.reward,
             'done': timestep.done,
         }
