@@ -1,17 +1,15 @@
 from easydict import EasyDict
-from ding.entry import serial_pipeline
 
 nstep = 3
-lunarlander_dqn_default_config = dict(
-    exp_name='lunarlander_dqn',
+lunarlander_dqn_config = dict(
+    exp_name='lunarlander_dqn_seed0',
     env=dict(
         # Whether to use shared memory. Only effective if "env_manager_type" is 'subprocess'
-        manager=dict(shared_memory=True, ),
         # Env number respectively for collector and evaluator.
         collector_env_num=8,
-        evaluator_env_num=5,
+        evaluator_env_num=8,
         env_id='LunarLander-v2',
-        n_evaluator_episode=5,
+        n_evaluator_episode=8,
         stop_value=200,
     ),
     policy=dict(
@@ -58,8 +56,8 @@ lunarlander_dqn_default_config = dict(
         ),
     ),
 )
-lunarlander_dqn_default_config = EasyDict(lunarlander_dqn_default_config)
-main_config = lunarlander_dqn_default_config
+lunarlander_dqn_config = EasyDict(lunarlander_dqn_config)
+main_config = lunarlander_dqn_config
 
 lunarlander_dqn_create_config = dict(
     env=dict(
@@ -73,4 +71,6 @@ lunarlander_dqn_create_config = EasyDict(lunarlander_dqn_create_config)
 create_config = lunarlander_dqn_create_config
 
 if __name__ == "__main__":
+    # or you can enter `ding -m serial -c lunarlander_dqn_config.py -s 0`
+    from ding.entry import serial_pipeline
     serial_pipeline([main_config, create_config], seed=0)
