@@ -1,15 +1,14 @@
 from easydict import EasyDict
-from ding.entry import serial_pipeline
 
 collector_env_num = 8
-evaluator_env_num = 5
+evaluator_env_num = 8
 lunarlander_r2d2_config = dict(
-    exp_name='debug_lunarlander_r2d2_n5_bs2_ul40_rbs5e4_seed1',
+    exp_name='lunarlander_r2d2_seed0',
     env=dict(
         collector_env_num=collector_env_num,
         evaluator_env_num=evaluator_env_num,
         env_id='LunarLander-v2',
-        n_evaluator_episode=5,
+        n_evaluator_episode=8,
         stop_value=200,
     ),
     policy=dict(
@@ -70,11 +69,13 @@ lunarlander_r2d2_create_config = dict(
         type='lunarlander',
         import_names=['dizoo.box2d.lunarlander.envs.lunarlander_env'],
     ),
-    env_manager=dict(type='base'),
+    env_manager=dict(type='subprocess'),
     policy=dict(type='r2d2'),
 )
 lunarlander_r2d2_create_config = EasyDict(lunarlander_r2d2_create_config)
 create_config = lunarlander_r2d2_create_config
 
 if __name__ == "__main__":
-    serial_pipeline([main_config, create_config], seed=0)
\ No newline at end of file
+    # or you can enter `ding -m serial -c lunarlander_r2d2_config.py -s 0`
+    from ding.entry import serial_pipeline
+    serial_pipeline([main_config, create_config], seed=0)
