@@ -1,23 +1,20 @@
 import os
 from easydict import EasyDict
 
-from ding.entry import serial_pipeline_r2d3
-
 module_path = os.path.dirname(__file__)
 
 collector_env_num = 8
-evaluator_env_num = 5
+evaluator_env_num = 8
 expert_replay_buffer_size = int(5e3)
 """agent config"""
 lunarlander_r2d3_config = dict(
-    exp_name='debug_lunarlander_r2d3_r2d2expert_k0_pho1-4_rbs1e4_ds5e3',
+    exp_name='lunarlander_r2d3_r2d2expert_seed0',
     env=dict(
         # Whether to use shared memory. Only effective if "env_manager_type" is 'subprocess'
-        manager=dict(shared_memory=True, reset_inplace=True),
         collector_env_num=collector_env_num,
         evaluator_env_num=evaluator_env_num,
         env_id='LunarLander-v2',
-        n_evaluator_episode=5,
+        n_evaluator_episode=8,
         stop_value=200,
     ),
     policy=dict(
@@ -89,17 +86,16 @@ lunarlander_r2d3_create_config = dict(
         type='lunarlander',
         import_names=['dizoo.box2d.lunarlander.envs.lunarlander_env'],
     ),
-    env_manager=dict(type='base'),
+    env_manager=dict(type='subprocess'),
     policy=dict(type='r2d3'),
 )
 lunarlander_r2d3_create_config = EasyDict(lunarlander_r2d3_create_config)
 create_config = lunarlander_r2d3_create_config
 """export config"""
 expert_lunarlander_r2d3_config = dict(
-    exp_name='expert_lunarlander_r2d3_r2d2expert_k0_pho1-4_ds5e3',
+    exp_name='expert_lunarlander_r2d3_r2d2expert_seed0',
     env=dict(
         # Whether to use shared memory. Only effective if "env_manager_type" is 'subprocess'
-        manager=dict(shared_memory=True, reset_inplace=True),
         collector_env_num=collector_env_num,
         evaluator_env_num=evaluator_env_num,
         n_evaluator_episode=5,
@@ -112,8 +108,6 @@ expert_lunarlander_r2d3_config = dict(
         model=dict(
             obs_shape=8,
             action_shape=4,
-            # encoder_hidden_size_list=[512, 64],  # dqn
-            # encoder_hidden_size_list=[128, 128, 64],  # ppo_off
             encoder_hidden_size_list=[128, 128, 512],  # r2d2
         ),
         discount_factor=0.997,
@@ -123,9 +117,10 @@ expert_lunarlander_r2d3_config = dict(
         collect=dict(
             # NOTE it is important that don't include key n_sample here, to make sure self._traj_len=INF
             each_iter_n_sample=32,
-            # Users should add their own path here (path should lead to a well-trained model)
-            # demonstration_info_path=module_path + '/demo_path/ppo-off_iteration_12948.pth.tar',
-            demonstration_info_path=module_path + '/demo_path/r2d2_iteration_13000.pth.tar',
+            # Users should add their own model path here. Model path should lead to a model.
+            # Absolute path is recommended.
+            # In DI-engine, it is ``exp_name/ckpt/ckpt_best.pth.tar``.
+            model_path='model_path_placeholder',
             # Cut trajectories into pieces with length "unroll_len". should set as self._unroll_len_add_burnin_step of r2d2
             unroll_len=
             40,  # TODO(pu): if in ppo_offpolicy, this key should equals self._unroll_len_add_burnin_step in r2d2 policy
@@ -150,11 +145,12 @@ expert_lunarlander_r2d3_create_config = dict(
         type='lunarlander',
         import_names=['dizoo.box2d.lunarlander.envs.lunarlander_env'],
     ),
-    env_manager=dict(type='base'),
+    env_manager=dict(type='subprocess'),
     policy=dict(type='r2d2_collect_traj'),  # this policy is designed to collect r2d2 expert traj for r2d3
 )
 expert_lunarlander_r2d3_create_config = EasyDict(expert_lunarlander_r2d3_create_config)
 expert_create_config = expert_lunarlander_r2d3_create_config
 
 if __name__ == "__main__":
+    from ding.entry import serial_pipeline_r2d3
     serial_pipeline_r2d3([main_config, create_config], [expert_main_config, expert_create_config], seed=0)
