@@ -2,8 +2,7 @@ from typing import Any, List, Union, Optional
 import time
 import gym
 import numpy as np
-from ding.envs import BaseEnv, BaseEnvTimestep, BaseEnvInfo
-from ding.envs.common.env_element import EnvElement, EnvElementInfo
+from ding.envs import BaseEnv, BaseEnvTimestep
 from ding.torch_utils import to_ndarray, to_list
 from ding.utils import ENV_REGISTRY
 from ding.envs.common import affine_transform
@@ -61,13 +60,11 @@ class LunarLanderEnv(BaseEnv):
         if self._act_scale:
             action = affine_transform(action, min_val=-1, max_val=1)
         obs, rew, done, info = self._env.step(action)
-        # self._env.render()
-        rew = float(rew)
         self._final_eval_reward += rew
         if done:
             info['final_eval_reward'] = self._final_eval_reward
         obs = to_ndarray(obs).astype(np.float32)
-        rew = to_ndarray([rew])  # wrapped to be transfered to a array with shape (1,)
+        rew = to_ndarray([rew]).astype(np.float32)  # wrapped to be transferred to a array with shape (1,)
         return BaseEnvTimestep(obs, rew, done, info)
 
     def enable_save_replay(self, replay_path: Optional[str] = None) -> None:
@@ -100,4 +97,4 @@ class LunarLanderEnv(BaseEnv):
         return self._reward_space
 
     def __repr__(self) -> str:
-        return "DI-engine LunarLander Env"
\ No newline at end of file
+        return "DI-engine LunarLander Env"
