@@ -1,7 +1,7 @@
 from easydict import EasyDict
 
 cartpole_c51_config = dict(
-    exp_name='cartpole_c51',
+    exp_name='cartpole_c51_seed0',
     env=dict(
         collector_env_num=8,
         evaluator_env_num=5,
@@ -53,3 +53,8 @@ cartpole_c51_create_config = dict(
 )
 cartpole_c51_create_config = EasyDict(cartpole_c51_create_config)
 create_config = cartpole_c51_create_config
+
+if __name__ == "__main__":
+    # or you can enter `ding -m serial -c cartpole_c51_config.py -s 0`
+    from ding.entry import serial_pipeline
+    serial_pipeline((main_config, create_config), seed=0)
