@@ -1,16 +1,17 @@
 from easydict import EasyDict
 
 cartpole_dqn_config = dict(
-    exp_name='cartpole_dqn',
+    exp_name='cartpole_dqn_seed0',
     env=dict(
         collector_env_num=8,
         evaluator_env_num=5,
         n_evaluator_episode=5,
         stop_value=195,
-        replay_path='cartpole_dqn/video',
+        replay_path='cartpole_dqn_seed0/video',
     ),
     policy=dict(
         cuda=False,
+        load_path='cartpole_dqn_seed0/ckpt/ckpt_best.pth.tar',  # necessary for eval
         model=dict(
             obs_shape=4,
             action_shape=2,
@@ -48,3 +49,8 @@ cartpole_dqn_create_config = dict(
 )
 cartpole_dqn_create_config = EasyDict(cartpole_dqn_create_config)
 create_config = cartpole_dqn_create_config
+
+if __name__ == "__main__":
+    # or you can enter `ding -m serial -c cartpole_dqn_config.py -s 0`
+    from ding.entry import serial_pipeline
+    serial_pipeline((main_config, create_config), seed=0)
