@@ -1,14 +1,10 @@
-import torch
 from easydict import EasyDict
 
-from ding.entry import serial_pipeline_reward_model_ngu
-
-print(torch.cuda.is_available(), torch.__version__)
 collector_env_num = 8
 evaluator_env_num = 5
 nstep = 5
 cartpole_ngu_config = dict(
-    exp_name='cartpole_ngu_bs20_n5_ul80_upc8_tuf2500_ed1e4_rbs1e5_debug',
+    exp_name='cartpole_ngu_seed0',
     env=dict(
         collector_env_num=collector_env_num,
         evaluator_env_num=evaluator_env_num,
@@ -92,7 +88,6 @@ cartpole_ngu_create_config = dict(
     ),
     env_manager=dict(type='base'),
     policy=dict(type='ngu'),
-    # TODO(pu)
     rnd_reward_model=dict(type='rnd'),
     episodic_reward_model=dict(type='episodic'),
     collector=dict(type='sample_ngu', )
@@ -101,5 +96,6 @@ cartpole_ngu_create_config = EasyDict(cartpole_ngu_create_config)
 create_config = cartpole_ngu_create_config
 
 if __name__ == "__main__":
-    # from ding.entry import serial_pipeline_reward_model_ngu
-    serial_pipeline_reward_model_ngu([main_config, create_config], seed=0)
+    # TODO: confirm which mode to be used in CLI
+    from ding.entry import serial_pipeline_ngu
+    serial_pipeline_ngu([main_config, create_config], seed=0)
