@@ -1,6 +1,7 @@
 from easydict import EasyDict
 
 pendulum_d4pg_config = dict(
+    exp_name='pendulum_d4pg_seed0',
     env=dict(
         collector_env_num=8,
         evaluator_env_num=5,
@@ -56,3 +57,8 @@ pendulum_d4pg_create_config = dict(
 )
 pendulum_d4pg_create_config = EasyDict(pendulum_d4pg_create_config)
 create_config = pendulum_d4pg_create_config
+
+if __name__ == "__main__":
+    # or you can enter `ding -m serial -c pendulum_d4pg_config.py -s 0`
+    from ding.entry import serial_pipeline
+    serial_pipeline([main_config, create_config], seed=0)
