@@ -1,7 +1,7 @@
 from easydict import EasyDict
 
 pendulum_sac_config = dict(
-    seed=0,
+    exp_name='pendulum_sac_seed0',
     env=dict(
         collector_env_num=10,
         evaluator_env_num=5,
@@ -55,3 +55,8 @@ pendulum_sac_create_config = dict(
 )
 pendulum_sac_create_config = EasyDict(pendulum_sac_create_config)
 create_config = pendulum_sac_create_config
+
+if __name__ == "__main__":
+    # or you can enter `ding -m serial -c pendulum_sac_config.py -s 0`
+    from ding.entry import serial_pipeline
+    serial_pipeline([main_config, create_config], seed=0)
