@@ -2,45 +2,13 @@ from typing import Any, List, Union, Sequence
 import copy
 import gym
 import numpy as np
-from ding.envs import BaseEnv, BaseEnvTimestep, BaseEnvInfo
-from ding.envs.common.env_element import EnvElement, EnvElementInfo
+from ding.envs import BaseEnv, BaseEnvTimestep
 from ding.utils import ENV_REGISTRY
 from ding.torch_utils import to_ndarray, to_list
 from .atari_wrappers import wrap_deepmind
 
 from pprint import pprint
 
-POMDP_INFO_DICT = {
-    'Pong-ramNoFrameskip-v4': BaseEnvInfo(
-        agent_num=1,
-        obs_space=EnvElementInfo(
-            shape=(128, ),
-            value={
-                'min': 0,
-                'max': 255,
-                'dtype': np.float32
-            },
-        ),
-        act_space=EnvElementInfo(
-            shape=(6, ),
-            value={
-                'min': 0,
-                'max': 6,
-                'dtype': np.float32
-            },
-        ),
-        rew_space=EnvElementInfo(
-            shape=1,
-            value={
-                'min': -1,
-                'max': 1,
-                'dtype': np.float32
-            },
-        ),
-        use_wrappers=None,
-    ),
-}
-
 
 def PomdpEnv(cfg, only_info=False):
     '''
@@ -75,6 +43,11 @@ class PomdpAtariEnv(BaseEnv):
         if not self._init_flag:
             self._env = self._make_env(only_info=False)
             self._init_flag = True
+            self._observation_space = self._env.observation_space
+            self._action_space = self._env.action_space
+            self._reward_space = gym.spaces.Box(
+                low=self._env.reward_range[0], high=self._env.reward_range[1], shape=(1, ), dtype=np.float32
+            )
         if hasattr(self, '_seed') and hasattr(self, '_dynamic_seed') and self._dynamic_seed:
             np_seed = 100 * np.random.randint(1, 1000)
             self._env.seed(self._seed + np_seed)
@@ -97,6 +70,7 @@ class PomdpAtariEnv(BaseEnv):
 
     def step(self, action: np.ndarray) -> BaseEnvTimestep:
         assert isinstance(action, np.ndarray), type(action)
+        action = action.item()
         obs, rew, done, info = self._env.step(action)
         self._final_eval_reward += rew
         obs = to_ndarray(obs)
@@ -105,16 +79,6 @@ class PomdpAtariEnv(BaseEnv):
             info['final_eval_reward'] = self._final_eval_reward
         return BaseEnvTimestep(obs, rew, done, info)
 
-    def info(self) -> BaseEnvInfo:
-        if self._cfg.env_id in POMDP_INFO_DICT:
-            info = copy.deepcopy(POMDP_INFO_DICT[self._cfg.env_id])
-            info.use_wrappers = self._make_env(only_info=True)
-            return info
-        else:
-            raise NotImplementedError(
-                '{} not found in POMDP_INFO_DICT [{}]'.format(self._cfg.env_id, POMDP_INFO_DICT.keys())
-            )  # noqa
-
     def _make_env(self, only_info=False):
         return wrap_deepmind(
             self._cfg.env_id,
@@ -143,3 +107,15 @@ class PomdpAtariEnv(BaseEnv):
         cfg = copy.deepcopy(cfg)
         cfg.is_train = False
         return [cfg for _ in range(evaluator_env_num)]
+
+    @property
+    def observation_space(self) -> gym.spaces.Space:
+        return self._observation_space
+
+    @property
+    def action_space(self) -> gym.spaces.Space:
+        return self._action_space
+
+    @property
+    def reward_space(self) -> gym.spaces.Space:
+        return self._reward_space
